KIWI—Next Generation
====================

.. |Build Status| image:: https://travis-ci.org/SUSE/kiwi.svg?branch=master
   :target: https://travis-ci.org/SUSE/kiwi
.. |Health| image:: https://landscape.io/github/SUSE/kiwi/master/landscape.svg?style=flat
   :target: https://landscape.io/github/SUSE/kiwi/master
.. |Doc| replace:: `Documentation <https://suse.github.io/kiwi>`__

|Build Status| |Health|

.. topic:: Abstract

    KIWI, the OS image and appliance builder.


* `Installation <https://suse.github.io/kiwi/quickstart.html>`__

* `Contributing <https://suse.github.io/kiwi/contributing.html>`__

* |Doc|




